package com.yzkj.scrtsdk.utils;
import java.io.File;
import java.io.FileReader;
import java.io.BufferedReader;
import java.io.IOException;

public class CallbackUrlUtils {
    public static String getCallbackUrl() throws IOException {
        // 1. 定位项目根目录下的 callbackUrl 文件
        File file = new File("callbackUrl");
        if (!file.exists() || file.isDirectory()) {
            throw new IOException("callbackUrl file not found in root directory");
        }

        // 2. 逐行读取文件内容
        try (BufferedReader reader = new BufferedReader(new FileReader(file))) {
            String line;
            while ((line = reader.readLine()) != null) {
                line = line.trim();
                // 跳过空行和注释行（以#开头）
                if (line.isEmpty() || line.startsWith("#")) continue;

                // 3. 解析 url 属性
                if (line.startsWith("url=")) {
                    String value = line.substring(4).trim();
                    // 去除值两侧的引号（支持单/双引号）
                    if (value.length() >= 2 &&
                            ( (value.startsWith("\"") && value.endsWith("\"")) ||
                                    (value.startsWith("'") && value.endsWith("'")) )) {
                        return value.substring(1, value.length() - 1);
                    }
                    return value;
                }
            }
        }

        throw new IOException("url property not found in callbackUrl file");
    }
    public static String getSecurityServerUrl() throws IOException {
        // 1. 定位项目根目录下的 callbackUrl 文件
        File file = new File("callbackUrl");
        if (!file.exists() || file.isDirectory()) {
            throw new IOException("callbackUrl file not found in root directory");
        }

        // 2. 逐行读取文件内容
        try (BufferedReader reader = new BufferedReader(new FileReader(file))) {
            String line;
            while ((line = reader.readLine()) != null) {
                line = line.trim();
                // 跳过空行和注释行（以#开头）
                if (line.isEmpty() || line.startsWith("#")) continue;

                // 3. 解析 url 属性
                if (line.startsWith("securityServerUrl=")) {
                    String value = line.substring(18).trim();
                    // 去除值两侧的引号（支持单/双引号）
                    if (value.length() >= 2 &&
                            ( (value.startsWith("\"") && value.endsWith("\"")) ||
                                    (value.startsWith("'") && value.endsWith("'")) )) {
                        return value.substring(1, value.length() - 1);
                    }
                    return value;
                }
            }
        }

        throw new IOException("url property not found in callbackUrl file");
    }
    // 测试代码
    public static void main(String[] args) {
        try {
            String url = CallbackUrlUtils.getCallbackUrl();
            System.out.println("读取到的URL: " + url);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
